@@ -1,10 +1,10 @@
 #!/bin/sh
 echo 'name: vector
-version: 0.7.0.1
-id: vector-0.7.0.1-3a18a3c369c7e19a25c6ed8559ed6128
+version: 0.7.1
+id: vector-0.7.1-8801549ab29457801fbe1eca2f7ad3c5
 
 license: BSD3
-copyright: (c) Roman Leshchinskiy 2008-2010
+copyright: (c) Roman Leshchinskiy 2008-2011
 maintainer: Roman Leshchinskiy <rl@cse.unsw.edu.au>
 stability:
 homepage: http://code.haskell.org/vector
@@ -37,6 +37,22 @@ description: .
              .
              * <http://trac.haskell.org/vector>
              .
+             Changes in version 0.7.1
+             .
+             * New functions: @iterateN@, @splitAt@
+             .
+             * New monadic operations: @generateM@, @sequence@, @foldM_@ and
+             variants
+             .
+             * New functions for copying potentially overlapping arrays: @move@,
+             @unsafeMove@
+             .
+             * Specialisations of various monadic operations for primitive monads
+             .
+             * Unsafe casts for Storable vectors
+             .
+             * Efficiency improvements
+             .
              Changes in version 0.7.0.1
              .
              * Dependency on package ghc removed
@@ -74,20 +90,20 @@ exposed-modules: Data.Vector.Internal.Check Data.Vector.Fusion.Util
                  Data.Vector.Unboxed.Base Data.Vector.Unboxed.Mutable
                  Data.Vector.Unboxed Data.Vector.Mutable Data.Vector
 hidden-modules:
-import-dirs: /usr/local/lib/ghc/vector-0.7.0.1
-library-dirs: /usr/local/lib/ghc/vector-0.7.0.1
-hs-libraries: HSvector-0.7.0.1
+import-dirs: /usr/local/lib/ghc/vector-0.7.1
+library-dirs: /usr/local/lib/ghc/vector-0.7.1
+hs-libraries: HSvector-0.7.1
 extra-libraries:
 extra-ghci-libraries:
-include-dirs: /usr/local/lib/ghc/vector-0.7.0.1/include
+include-dirs: /usr/local/lib/ghc/vector-0.7.1/include
 includes:
-depends: base-4.3.1.0-e1ba2d2213b66179f3e0c901a27d3a96
-         primitive-0.3.1-8254baf92d822508a6aa7805b8b44531
+depends: base-4.3.1.0-4365831fa9af03083be195ed161cbbc1
+         primitive-0.3.1-c9e4468cc744c0e030467f8c31383955
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-vector-0.7.0.1/html/vector.haddock
-haddock-html: /usr/local/share/doc/hs-vector-0.7.0.1/html
+haddock-interfaces: /usr/local/share/doc/hs-vector-0.7.1/html/vector.haddock
+haddock-html: /usr/local/share/doc/hs-vector-0.7.1/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
